@@ -1,8 +1,8 @@
 mod structs;
 mod traits;
 pub use structs::cash::Cash;
-use traits::create::Procedures;
-use traits::calculate::Operations;
+pub use traits::create::Procedures;
+pub use traits::calculate::Operations;
 
 fn cristi() {
     let wallet: Cash = Cash::create(String::from("eur"), 2);
